@@ -56,6 +56,16 @@ django-geckoboard decorator::
         midnight = datetime.combine(date.today(), time.min)
         return Comment.objects.filter(submit_date__gte=midnight).count()
 
+
+If your widget has optional settings, you can pass them in the decorator
+definition::
+
+    @number_widget(absolute='true')
+    def comment_count(request):
+        midnight = datetime.combine(date.today(), time.min)
+        return Comment.objects.filter(submit_date__gte=midnight).count()
+
+
 Then use a URLconf module to map a URL to the view::
 
     from django.conf.urls.defaults import *
@@ -97,11 +107,12 @@ The following decorators are available from the
 
 Render a *Number & Secondary Stat* widget.
 
-The decorated view must return a tuple *(current, [previous])*, where
-the *current* parameter is the current value and optional *previous*
-parameter is the previous value of the measured quantity.  If there is
-only one parameter you do not need to return it in a tuple.  For
-example, to render a widget that shows the number of users and the
+The decorated view must return a tuple *(current, [previous],
+[prefix])* where the *current* parameter is the current value, optional
+*previous* parameter is the previous value of the measured quantity and
+the optional parameter *prefix* is the prefix used in Geckoboard widget.
+If there is only one parameter you do not need to return it in a tuple.
+For example, to render a widget that shows the number of users and the
 difference from last week::
 
     from django_geckoboard.decorators import number_widget
@@ -115,6 +126,13 @@ difference from last week::
         last_week_users = users.filter(date_joined__lt=last_week)
         return (users.count(), last_week_users.count())
 
+    @number_widget
+    def users_count_with_prefix(request):
+        last_week = datetime.now() - timedelta(weeks=1)
+        users = User.objects
+        last_week_users = users.filter(date_joined__lt=last_week)
+        return (users.count(), last_week_users.count(), '$')
+
 
 ``rag_widget``
 --------------
@@ -336,6 +354,6 @@ http://support.geckoboard.com/entries/274940-custom-chart-widget-type-definition
 
 __author__ = "Joost Cassee"
 __email__ = "joost@cassee.net"
-__version__ = "1.2.4"
+__version__ = "1.2.6"
 __copyright__ = "Copyright (C) 2011 Joost Cassee and others"
 __license__ = "MIT License"
